errcode

package
v0.3.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

Package errcode provides a list of QUIC application error codes for communication between the game client and the game server.

Index

Constants

const (
	Unknown = quic.StreamErrorCode(iota + 1)
	HostClosed
	PeerClosed
	HostInternalError
	PeerInternalError
	Cancelled
)

Stream error codes.

const (
	Exit = http3.ErrCode(0)
)

Application error codes.

Variables

This section is empty.

Functions

func IsLocalHTTPError added in v0.1.0

func IsLocalHTTPError(err error, code quic.StreamErrorCode) bool

IsLocalHTTPError returns true if the error is local HTTP/3 error with the given code.

func IsLocalQUICConnClosed

func IsLocalQUICConnClosed(err error) bool

IsLocalQUICConnClosed returns true if the error is local QUIC stream closed.

func IsLocalStreamError

func IsLocalStreamError(err error, code quic.StreamErrorCode) bool

IsLocalStreamError returns true if the error is local QUIC stream error with the given code.

func IsRemoteQUICConnClosed

func IsRemoteQUICConnClosed(err error) bool

IsRemoteQUICConnClosed returns true if the error is remote QUIC stream closed.

func IsRemoteStreamError

func IsRemoteStreamError(err error, code quic.StreamErrorCode) bool

IsRemoteStreamError returns true if the error is remote QUIC stream error with the given code.

Types

This section is empty.

Jump to