Documentation
¶
Overview ¶
Package errcode provides a list of QUIC application error codes for communication between the game client and the game server.
Index ¶
Constants ¶
const ( Unknown = quic.StreamErrorCode(iota + 1) HostClosed PeerClosed HostInternalError PeerInternalError Cancelled )
Stream error codes.
const (
Exit = http3.ErrCode(0)
)
Application error codes.
Variables ¶
This section is empty.
Functions ¶
func IsLocalHTTPError ¶ added in v0.1.0
func IsLocalHTTPError(err error, code quic.StreamErrorCode) bool
IsLocalHTTPError returns true if the error is local HTTP/3 error with the given code.
func IsLocalQUICConnClosed ¶
IsLocalQUICConnClosed returns true if the error is local QUIC stream closed.
func IsLocalStreamError ¶
func IsLocalStreamError(err error, code quic.StreamErrorCode) bool
IsLocalStreamError returns true if the error is local QUIC stream error with the given code.
func IsRemoteQUICConnClosed ¶
IsRemoteQUICConnClosed returns true if the error is remote QUIC stream closed.
func IsRemoteStreamError ¶
func IsRemoteStreamError(err error, code quic.StreamErrorCode) bool
IsRemoteStreamError returns true if the error is remote QUIC stream error with the given code.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.