Documentation
¶
Index ¶
Constants ¶
const MTU = 1200
MTU is a safe maximum size of a UDP packet.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type LocalDialer ¶
type Queue ¶ added in v0.3.0
type Queue[T any] struct { // contains filtered or unexported fields }
Queue is a simple FIFO queue backed by a ring buffer. Zero value is a Queue backed by empty slice.
func (*Queue[T]) Peek ¶ added in v0.3.0
Peek returns the first element of the queue without removing it, or false if the queue is empty.
type TTLMap ¶ added in v0.3.0
type TTLMap[K comparable, V any] struct { // contains filtered or unexported fields }
TTLMap is a map where items are evicted after they are not accessed for a certain duration.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package udp provides a UDP-based implementation of net.Conn.
|
Package udp provides a UDP-based implementation of net.Conn. |
Click to show internal directories.
Click to hide internal directories.